dm_epoch_test: Test superposed epoch composites against a null distribution

View source: R/dm_sea.R

dm_epoch_testR Documentation

Test superposed epoch composites against a null distribution

Description

Tests observed superposed epoch composites against empirical null distributions generated by randomly sampled anchor times.

If the input object was created with Year and/or DOY filters in [dm_epoch_extract()] and restrict_null_to_window = TRUE, null anchors are sampled from the same calendar-year and day-of-year window.

Usage

dm_epoch_test(
  x,
  statistic = c("mean", "median"),
  null = c("same_doy_window", "same_month", "random_time"),
  n_iter = 1000,
  doy_window = 15,
  match_hour = TRUE,
  match_minute = TRUE,
  conf_level = 0.95,
  seed = NULL
)

Arguments

x

Object returned by [dm_epoch_extract()].

statistic

Composite statistic. One of "mean" or "median".

null

Null model. One of "same_doy_window", "same_month", or "random_time".

n_iter

Number of null iterations.

doy_window

DOY window used for null = "same_doy_window".

match_hour

Logical. For hourly or minute data, keep the same hour when possible.

match_minute

Logical. For minute data, keep the same minute when possible.

conf_level

Confidence level for null envelopes.

seed

Optional random seed.

Value

An object of class c("dm_epoch", "dm_epoch_test").


dendRoAnalyst documentation built on May 20, 2026, 5:07 p.m.