dmea_sample_anchor_one: Sample one null anchor time

View source: R/dm_sea.R

dmea_sample_anchor_oneR Documentation

Sample one null anchor time

Description

Sample one null anchor time

Usage

dmea_sample_anchor_one(
  event_time,
  clim_times,
  null = c("same_doy_window", "same_month", "random_time"),
  doy_window = 15,
  match_hour = TRUE,
  match_minute = TRUE,
  unit = c("hours", "days", "mins")
)

Arguments

event_time

Original event time.

clim_times

Candidate climate timestamps.

null

Null model. One of "same_doy_window", "same_month", or "random_time".

doy_window

DOY window used for null = "same_doy_window".

match_hour

Logical. For hourly or minute data, keep the same hour when possible.

match_minute

Logical. For minute data, keep the same minute when possible.

unit

One of "hours", "days", or "mins".

Value

One sampled POSIXct timestamp.


dendRoAnalyst documentation built on May 20, 2026, 5:07 p.m.