View source: R/plot.dm_growth_fit.R
| dmgp_prepare_curve_groups | R Documentation |
Internal helper used by [plot.dm_growth_fit()] to define panel identifiers, facet variables, colour groups, and legend titles.
dmgp_prepare_curve_groups(dat, facet_by = c("default", "tree", "year", "none"))
dat |
Tidy plotting data returned by [dmgp_tidy_fit_data()]. |
facet_by |
Character string controlling faceting layout. |
A list containing modified plotting data and faceting settings.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.