dmgp_prepare_timing_plot_data: Prepare timing-summary plot data

View source: R/plot.dm_growth_fit.R

dmgp_prepare_timing_plot_dataR Documentation

Prepare timing-summary plot data

Description

Internal helper used by [plot.dm_growth_fit()] to prepare the line segments, point markers, and labels used in type = "timing" plots.

Usage

dmgp_prepare_timing_plot_data(
  fit_statistics,
  facet_by = c("default", "tree", "year", "none"),
  x_mode = c("date", "doy", "season_day"),
  series = NULL,
  fit_id = NULL
)

Arguments

fit_statistics

Fit-statistics table from a "dm_growth_fit" object.

facet_by

Faceting mode.

x_mode

Timing coordinate system. One of "date", "doy", or "season_day".

series

Optional series filter.

fit_id

Optional fit identifier filter.

Value

A list of data frames used by the timing plot.


dendRoAnalyst documentation built on May 20, 2026, 5:07 p.m.