dmgp_resolve_x_axis: Resolve x-axis mode for dendrometer growth-fit plots

View source: R/plot.dm_growth_fit.R

dmgp_resolve_x_axisR Documentation

Resolve x-axis mode for dendrometer growth-fit plots

Description

Internal helper used by [plot.dm_growth_fit()] to determine which column is used on the x-axis and which timing coordinate system should be used.

Usage

dmgp_resolve_x_axis(type, x_axis = c("default", "season_day", "doy", "date"))

Arguments

type

Plot type.

x_axis

Requested x-axis representation.

Value

A list with elements var, label, and timing_mode.


dendRoAnalyst documentation built on May 20, 2026, 5:07 p.m.