plot.dm_growth_evaluation: Plot growth-fitting evaluation statistics

View source: R/plot.dm_growth_evaluation.R

plot.dm_growth_evaluationR Documentation

Plot growth-fitting evaluation statistics

Description

Creates ggplot2-based comparison plots for objects returned by [dm.growth.evaluate()].

Usage

## S3 method for class 'dm_growth_evaluation'
plot(
  x,
  metric = c("rmse", "mae", "bias", "abs_bias", "r2", "correlation", "nrmse", "rss",
    "aic_approx", "bic_approx"),
  type = c("boxplot", "mean", "heatmap"),
  order_methods = TRUE,
  decreasing = NULL,
  show_points = TRUE,
  show_errorbar = TRUE,
  heatmap_label = c("series_fit", "series", "fit_id"),
  na.rm = TRUE,
  ...
)

Arguments

x

An object of class "dm_growth_evaluation".

metric

Evaluation metric to plot. One of "rmse", "mae", "bias", "abs_bias", "r2", "correlation", "nrmse", "rss", "aic_approx", or "bic_approx".

type

Plot type. One of "boxplot", "mean", or "heatmap".

order_methods

Logical. If TRUE, methods are ordered by their average value for the chosen metric.

decreasing

Logical or NULL. Controls method ordering. If NULL, metrics where smaller values are better are ordered ascending, and metrics where larger values are better are ordered descending.

show_points

Logical. If TRUE, add individual fit points to "boxplot" and "mean" displays.

show_errorbar

Logical. If TRUE, show standard-error bars when type = "mean".

heatmap_label

Character string used to label rows in the heatmap. One of "series_fit", "series", or "fit_id".

na.rm

Logical. If TRUE, remove missing metric values before plotting.

...

Further arguments passed to plotting methods.

Value

A ggplot object.

See Also

[dm.growth.evaluate()]


dendRoAnalyst documentation built on May 20, 2026, 5:07 p.m.