plot_event_climate_box: Plot event-based climate distributions

View source: R/events_phase_plots.R

plot_event_climate_boxR Documentation

Plot event-based climate distributions

Description

Draws boxplots or violins of event-based climate variables across phases or event types, with optional significance annotation.

Usage

plot_event_climate_box(
  event_data,
  climate_var,
  group_var = c("Phase", "event_type"),
  facet_by = c("none", "month", "month_of_year", "year"),
  Year = NULL,
  DOY = NULL,
  geom = c("boxplot", "violin", "both"),
  add_test = TRUE,
  test_method = c("auto", "anova", "kruskal", "t.test", "wilcox"),
  point_alpha = 0.5
)

Arguments

event_data

Output of dm_event_climate().

climate_var

Name of the climate-derived column to plot.

group_var

Grouping variable. One of "Phase" or "event_type".

facet_by

One of "none", "month", "month_of_year", or "year".

Year

Optional numeric year or vector of years for filtering.

DOY

Optional numeric vector of length 2 for filtering.

geom

One of "boxplot", "violin", or "both".

add_test

Logical. If TRUE, adds per-panel test results.

test_method

Passed to dm_event_climate_test().

point_alpha

Point transparency.

Value

A ggplot2 object.

Examples


data(gf_nepa17)
data(ktm_clim_hourly)

zg <- phase.zg(df = gf_nepa17[1:800, ], TreeNum = 1)
evt_zg <- dm_event_climate(
  zg,
  ktm_clim_hourly,
  event = "phase_start",
  windows = c(0, 3, 6, 12, 24),
  mean_vars = c("temp", "VPD", "RH"),
  max_vars  = c("VPD"),
  sum_vars  = c("prec")
)

if (any(!is.na(evt_zg$VPD_mean_prev_6h))) {
  plot_event_climate_box(
    evt_zg,
    climate_var = "VPD_mean_prev_6h",
    group_var = "Phase",
    facet_by = "month_of_year",
    geom = "both",
    add_test = TRUE
  )
}



dendRoAnalyst documentation built on May 20, 2026, 5:07 p.m.