summary.dm_wavelet_reconstruct: Summarize a dm_wavelet_reconstruct object

View source: R/dm_wavelet_reconstruct.R

summary.dm_wavelet_reconstructR Documentation

Summarize a dm_wavelet_reconstruct object

Description

Summarizes the output of dm_wavelet_reconstruct().

For each reconstructed series, the summary reports:

  • number of observations,

  • variance of the original series,

  • variance of the reconstructed component,

  • variance of the remaining component,

  • variance of the returned filtered series,

  • proportion of original variance represented by reconstructed and filtered series,

  • correlation and R^2 between original and reconstructed,

  • number and range of periods used in reconstruction.

Usage

## S3 method for class 'dm_wavelet_reconstruct'
summary(object, ...)

Arguments

object

An object of class "dm_wavelet_reconstruct".

...

Further arguments passed to or from other methods.

Value

An object of class "summary.dm_wavelet_reconstruct" with elements:

overview

One-row summary of the reconstruction object.

series_summary

Per-series summary table.

used_periods

The table of periods actually used in the reconstruction.

selection

The selection settings used for reconstruction.


dendRoAnalyst documentation built on May 20, 2026, 5:07 p.m.