powered by
This function detrends the dendrometer data either using first difference or using gam function from mgcv package or the Gompertz function.
mgcv
dm.detrend(df, method = "gam", CalYear)
A dataframe with the detrended dendrometer series.
dataframe with first column containing date and time in the format yyyy-mm-dd HH:MM:SS and the dendrometer data in following columns.
yyyy-mm-dd HH:MM:SS
either 'f_diff', 'gam' or 'gomp' indicating the method to detrend the dendrometer data column in df.
numeric for year of calculation. If df has more than one year, assigning CalYear truncates the data of only that year.
library(dendRoAnalyst) data(gf_nepa17) detrended<-dm.detrend(df=nepa17, method='f_diff', CalYear=2017) head(detrended,10)
Run the code above in your browser using DataLab