View source: R/dm.fit.gompertz.R
| dm.fit.gompertz | R Documentation |
This function modells the annual growth of dendrometer data using gompertz function.
dm.fit.gompertz(
df,
CalYear,
TreeNum,
f_derivative = F,
start = list(b = 0.5, k = 0.005),
verbose = FALSE
)
df |
dataframe with first column containing date and time in the format |
CalYear |
numeric for year of calculation. If df has more than one year, assigning CalYear truncates the data of only that year. |
TreeNum |
numerical value indicating the tree to be analysed. E.g. '1' refers to the first dendrometer data column in df. |
f_derivative |
logical if yes returns first derivative of gompertz curve. |
start |
A named list of start values for fitting
the Gompertz curve (passed to |
verbose |
logical if TRUE also returns the optimized parameters. Default is FALSE. |
A data frame with the modelled dendrometer series. If verbose = TRUE, returns a list
with two data frames. The fitted curve and parameters.
library(dendRoAnalyst)
data(gf_nepa17)
gomp_fitted<-dm.fit.gompertz(df=gf_nepa17, TreeNum = 1, CalYear=2017)
head(gomp_fitted,10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.