Learn R Programming

dendRoAnalyst (version 0.1.5)

dm.fit.gompertz: Fitting gompertz function on annual dendrometer data

Description

This function modells the annual growth of dendrometer data using gompertz function.

Usage

dm.fit.gompertz(df, CalYear, TreeNum, f_derivative = F)

Value

A dataframe with the modelled dendrometer series.

Arguments

df

dataframe with first column containing date and time in the format yyyy-mm-dd HH:MM:SS and the dendrometer data in following columns.

CalYear

numeric for year of calculation. If df has more than one year, assigning CalYear truncates the data of only that year.

TreeNum

numerical value indicating the tree to be analysed. E.g. '1' refers to the first dendrometer data column in df.

f_derivative

logical if yes returns first derivative of gompertz curve.

Examples

Run this code
library(dendRoAnalyst)
data(gf_nepa17)
gomp_fitted<-dm.fit.gompertz(df=gf_nepa17, TreeNum = 1, CalYear=2017)
head(gomp_fitted,10)

Run the code above in your browser using DataLab