powered by
This function modells the annual growth of dendrometer data using gompertz function.
dm.fit.gompertz(df, CalYear, TreeNum, f_derivative = F)
A dataframe with the modelled dendrometer series.
dataframe with first column containing date and time in the format yyyy-mm-dd HH:MM:SS and the dendrometer data in following columns.
yyyy-mm-dd HH:MM:SS
numeric for year of calculation. If df has more than one year, assigning CalYear truncates the data of only that year.
numerical value indicating the tree to be analysed. E.g. '1' refers to the first dendrometer data column in df.
logical if yes returns first derivative of gompertz curve.
library(dendRoAnalyst) data(gf_nepa17) gomp_fitted<-dm.fit.gompertz(df=gf_nepa17, TreeNum = 1, CalYear=2017) head(gomp_fitted,10)
Run the code above in your browser using DataLab