| dm_epoch_test | R Documentation |
Tests observed superposed epoch composites against empirical null distributions generated by randomly sampled anchor times.
If the input object was created with Year and/or DOY filters
in [dm_epoch_extract()] and restrict_null_to_window = TRUE, null
anchors are sampled from the same calendar-year and day-of-year window.
dm_epoch_test(
x,
statistic = c("mean", "median"),
null = c("same_doy_window", "same_month", "random_time"),
n_iter = 1000,
doy_window = 15,
match_hour = TRUE,
match_minute = TRUE,
conf_level = 0.95,
seed = NULL
)
x |
Object returned by [dm_epoch_extract()]. |
statistic |
Composite statistic. One of |
null |
Null model. One of |
n_iter |
Number of null iterations. |
doy_window |
DOY window used for |
match_hour |
Logical. For hourly or minute data, keep the same hour when possible. |
match_minute |
Logical. For minute data, keep the same minute when possible. |
conf_level |
Confidence level for null envelopes. |
seed |
Optional random seed. |
An object of class c("dm_epoch", "dm_epoch_test").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.