| dmea_sample_anchor_one | R Documentation |
Sample one null anchor time
dmea_sample_anchor_one(
event_time,
clim_times,
null = c("same_doy_window", "same_month", "random_time"),
doy_window = 15,
match_hour = TRUE,
match_minute = TRUE,
unit = c("hours", "days", "mins")
)
event_time |
Original event time. |
clim_times |
Candidate climate timestamps. |
null |
Null model. One of |
doy_window |
DOY window used for |
match_hour |
Logical. For hourly or minute data, keep the same hour when possible. |
match_minute |
Logical. For minute data, keep the same minute when possible. |
unit |
One of |
One sampled POSIXct timestamp.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.