| dmea_time_filter_index | R Documentation |
Internal helper used by the SEA functions to select timestamps by calendar year and day-of-year.
dmea_time_filter_index(times, Year = NULL, DOY = NULL)
times |
A vector of date-time values. |
Year |
Optional numeric vector of calendar years to retain. |
DOY |
Optional numeric vector of length one or two. If length one, only
that day-of-year is retained. If length two, the inclusive DOY range is
retained. If the first value is larger than the second, the range is treated
as a cross-year DOY window, for example |
A logical vector with the same length as times.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.