View source: R/plot.dm_growth_fit.R
| dmgp_resolve_x_axis | R Documentation |
Internal helper used by [plot.dm_growth_fit()] to determine which column is used on the x-axis and which timing coordinate system should be used.
dmgp_resolve_x_axis(type, x_axis = c("default", "season_day", "doy", "date"))
type |
Plot type. |
x_axis |
Requested x-axis representation. |
A list with elements var, label, and
timing_mode.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.