View source: R/plot.dm_growth_fit.R
| dmgp_tidy_fit_data | R Documentation |
Internal helper used by [plot.dm_growth_fit()] to combine fitted and observed daily dendrometer growth data into a long-format plotting table.
dmgp_tidy_fit_data(x, observed_source = c("processed", "original_daily"))
x |
An object of class |
observed_source |
Character string. Either |
A tibble containing fitted values, observed values, series labels, fit identifiers, and panel identifiers.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.