| i.jump.locator | R Documentation |
Dendrometers generally have limited memory capacity beyond which they stop recording. To keep the measurement ongoing, they should be adjusted periodically, which can cause positive or negative jumps in the data. This function locates these artefacts and interactively adjusts them one by one.
i.jump.locator(
df,
TreeNum,
detection_method = c("manual", "auto"),
manual_threshold = NULL,
auto_method_penalty = 10,
adjustment_method = c("window_median", "point_diff"),
adjust_window = 5,
plot_window = 20,
auto_every_second = TRUE,
set_jump_point_na = FALSE
)
df |
Data frame with first column containing date and time in the format
|
TreeNum |
Numerical value indicating the tree to be analysed. E.g. |
detection_method |
Either |
manual_threshold |
Numeric threshold considered as artefact when
|
auto_method_penalty |
Numeric manual penalty value used in
|
adjustment_method |
Either |
adjust_window |
Integer window size used for robust jump-size estimation
when |
plot_window |
Integer number of points shown before and after each jump in the interactive plot. |
auto_every_second |
Logical. If |
set_jump_point_na |
Logical. If |
A dataframe containing jump-free dendrometer data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.