| jump.locator | R Documentation |
Dendrometers generally have limited memory capacity beyond which
they stop recording. To keep the measurement ongoing, they should be adjusted
periodically, which can cause positive or negative jumps in the data. This
function locates these artefacts and adjusts them automatically. Unlike
i.jump.locator , it can handle datasets with more than one
dendrometer.
jump.locator(
df,
detection_method = c("manual", "auto"),
manual_threshold = NULL,
auto_method_penalty = 10,
adjustment_method = c("window_median", "point_diff"),
adjust_window = 5,
auto_every_second = TRUE,
set_jump_point_na = FALSE
)
df |
Data frame with first column containing date and time in the format
|
detection_method |
Either |
manual_threshold |
Numeric threshold considered as artefact when
|
auto_method_penalty |
Numeric manual penalty value used in
|
adjustment_method |
Either |
adjust_window |
Integer window size used for robust jump-size estimation
when |
auto_every_second |
Logical. If |
set_jump_point_na |
Logical. If |
A dataframe containing jump-free dendrometer data.
library(dendRoAnalyst)
data(nepa)
# Manual detection
jump_free_nepa <- jump.locator(
df = nepa,
detection_method = "manual",
manual_threshold = 1
)
# Automatic detection with cpt.mean() and penalty = "Manual"
jump_free_nepa2 <- jump.locator(
df = nepa,
detection_method = "auto",
auto_method_penalty = 10
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.