Learn R Programming

dendRoAnalyst (version 0.1.5)

jump.locator: Removing artefacts due to manual adjustments of dendrometers automatically for more than one dendrometers

Description

Dendrometers generally have limited memory capacity beyond which it stops recording. To keep the measurement ongoing, they should be adjusted periodically, which can cause positive or negative jumps in the data. This function locates these artefacts and adjusts them.Unlike in i.jump.locator, it can handle dataset with more than one dendrometers.

Usage

jump.locator(df, v)

Value

A dataframe containing jump-free dendrometer data.

Arguments

df

dataframe with first column containing date and time in the format yyyy-mm-dd HH:MM:SS and the dendrometer data in following columns.

v

numerical value which is considered as artefact. E.g. v=1 implies that if the difference to the consecutive data point is more than 1 or less than -1, it will be considered as an artefact.

Examples

Run this code
library(dendRoAnalyst)
data(nepa)
jump_free_nepa<-jump.locator(df=nepa ,v=1)
head(jump_free_nepa,10)

Run the code above in your browser using DataLab