View source: R/plot_dm.detrend.R
| plot.dm_detrended | R Documentation |
S3 plotting method for objects returned by [dm.detrend.fit()].
The default plot compares:
original daily dendrometer series,
fitted curve reconstructed on the original daily scale,
residuals ('observed - fitted_original'),
detrended standardized series.
## S3 method for class 'dm_detrended'
plot(
x,
y = NULL,
type = c("compare", "fit", "residual", "detrended", "boxplot"),
series = NULL,
seasons = NULL,
x_axis = c("default", "date", "season_day", "doy"),
facet_by = c("series", "season", "none"),
ncol = NULL,
box_group = c("series", "season"),
show_observed = TRUE,
show_fitted = TRUE,
point_alpha = 0.7,
line_width = 0.8,
legend_position = "right",
...
)
x |
An object of class |
y |
Unused. |
type |
Plot type. One of:
|
series |
Optional character vector of dendrometer series to plot.
Default is |
seasons |
Optional character vector of vegetation-season labels to plot.
Default is |
x_axis |
Character string controlling the x-axis. One of:
|
facet_by |
Character string controlling faceting. One of:
|
ncol |
Optional integer giving the number of columns in faceted plots where [ggplot2::facet_wrap()] is used. |
box_group |
For |
show_observed |
Logical. If |
show_fitted |
Logical. If |
point_alpha |
Numeric alpha level used for observed points. Default is
|
line_width |
Numeric line width used for fitted, residual, and detrended
lines. Default is |
legend_position |
Character string specifying legend position.
Default is |
... |
Further arguments passed to or from other methods. |
A ggplot2 object.
fit1 <- dm.growth.fit(
df = gf_nepa17,
TreeNum = 1:2,
method = "gompertz",
year_mode = "yearly",
verbose = FALSE
)
det1 <- dm.detrend.fit(fit1)
plot(det1)
plot(det1, type = "fit")
plot(det1, type = "residual")
plot(det1, type = "detrended")
plot(det1, type = "boxplot")
plot(det1, type = "compare", facet_by = "series")
plot(det1, type = "compare", facet_by = "season")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.