View source: R/dm_wavelet_reconstruct.R
| summary.dm_wavelet_reconstruct | R Documentation |
Summarizes the output of dm_wavelet_reconstruct().
For each reconstructed series, the summary reports:
number of observations,
variance of the original series,
variance of the reconstructed component,
variance of the remaining component,
variance of the returned filtered series,
proportion of original variance represented by reconstructed and filtered series,
correlation and R^2 between original and reconstructed,
number and range of periods used in reconstruction.
## S3 method for class 'dm_wavelet_reconstruct'
summary(object, ...)
object |
An object of class |
... |
Further arguments passed to or from other methods. |
An object of class "summary.dm_wavelet_reconstruct" with elements:
One-row summary of the reconstruction object.
Per-series summary table.
The table of periods actually used in the reconstruction.
The selection settings used for reconstruction.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.